//
// MoonCanvas.h
// Draw the moon and related info.
//
//    Copyright 2002 by Akkana Peck.
// You may use or distribute this code under the terms of the GPL.
//

//
// In order to port QMoon to a new platform,
// subclass MoonCanvas and implement all the pure virtuals.
//

#ifndef MOONCANVAS_H
#define MOONCANVAS_H

class MoonFeature;

class MoonCanvas
{
public:
    MoonCanvas();
    virtual ~MoonCanvas();

    void Init();

    //
    // Subclasses must implement the following methods
    // in order to make a new front-end for this program:
    //
    virtual void ToggleMirrored();
    virtual void Zoom(int level) = 0;

    virtual void Clear() = 0;
    virtual void Paint() = 0;

    virtual void SetColor(int r, int g, int b) = 0;

    virtual void DrawLine(int x1, int y1, int x2, int y2) = 0;
    virtual void DrawEllipse(int x, int y, int w, int h) = 0;
    virtual void DrawString(char* str, int x, int y) = 0;

    virtual int Width() = 0;
    virtual int Height() = 0;
    //
    // End methods which subclasses must implement.
    //

    virtual void MousePress(int x, int y, int btnNum, int clickNum);
    virtual void MouseRelease(int x, int y, int btnNum, int clickNum);

    // Paint one feature:
    virtual void PaintFeature(MoonFeature* feature);

    // Paint all features:
    virtual void PaintFeatures();

    static void SetDebugMode(int yes) { sDebugMode = yes; };

protected:
    int mMoonRadius;
    int mMoonCenterX, mMoonCenterY;
    int mMirrored;
    int mZoomLevel;
    int mMinLong, mMaxLong;
    int mMinLat, mMaxLat;

    int mCraterNum;
#define MAX_OBJECTS_SHOWN 6
    MoonFeature* mMatches[MAX_OBJECTS_SHOWN];

    static int sDebugMode;

    // All images have some inherent libration, alas.  Compensate:
    int mImgLibrationE;
    int mImgLibrationN;
};

#endif // MOONCANVAS_H
