//
// Mare.cpp
// A mare on the moon.
//
//    Copyright 2002 by Akkana Peck.
// You may use or distribute this code under the terms of the GPL.
//

#include "Mare.h"

#include <math.h>
#include <string.h>
#include <stdlib.h>
#include <stdio.h>

// Static variables:
Mare::Mare() : MoonFeature()
{
}

Mare::Mare(char* name, char* desc, int sizeX, int sizeY,
           int longitude, int latitude)
{
    Init(name, desc, sizeX, sizeY, longitude, latitude);
}

void
Mare::Init(char* name, char* desc, int sizeX, int sizeY,
           int longitude, int latitude)
{
    mName = strdup(name);
    if (desc)
        mDesc = strdup(desc);
    else
        mDesc = 0;
    mSizeX = sizeX;
    mSizeY = sizeY;
    mSize = (sizeX + sizeY) / 2;
    mLongitude = longitude;
    mLatitude = latitude;
}

Mare::~Mare()
{
    if (mName) delete[] mName;
    if (mDesc) delete[] mDesc;
}

int Mare::GetSizeX()    { return mSizeX; }

int Mare::GetSizeY()    { return mSizeY; }

// Routines for looping over all known maria:
void
Mare::InitMaria()
{
    if (!sMoonFeatureList)
        return;

    char* mareFileName = DATADIR "maria.dat";
    FILE* cfile = fopen(mareFileName, "r");
    if (!cfile)
        return;

    char line[BUFSIZ];
    while (fgets(line, sizeof line, cfile) != 0)
    {
        if (*line == '#')       // Skip comments
            continue;
        int latitude = (int)atof(line+30);
        if (line[36] == 'S')
            latitude = -latitude;
        int longitude = (int)atof(line+38);
        if (line[44] == 'W')
            longitude = -longitude;
        // Write a null after the name in the line buffer,
        // so we can pass it to strdup:
        int i;
        for (i=28; i>0 && line[i] == ' '; --i)
            ;
        if (i <= 0)
            return;

        line[i+1] = '\0';

        sMoonFeatureList[sNumFeatures++] = new Mare(line, line+66,
                                                    (int)atof(line+47),
                                                    (int)atof(line+56),
                                                    longitude, latitude);
    }
    printf("%d maria loaded\n", sNumFeatures);
}

